@@ -13,7 +13,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: ipsec_xform.c,v 1.65.2.1 2006-10-06 21:39:26 paul Exp $
+ * RCSID $Id: ipsec_xform.c,v 1.65 2005/04/29 05:10:22 mcr Exp $
  */
 
 #ifndef AUTOCONF_INCLUDED
@@ -57,8 +57,8 @@
 #include "freeswan/ipsec_ah.h"
 #include "freeswan/ipsec_esp.h"
 
-#include <pfkeyv2.h>
-#include <pfkey.h>
+#include <openswan/pfkeyv2.h>
+#include <openswan/pfkey.h>
 
 #ifdef CONFIG_KLIPS_DEBUG
 int debug_xform = 0;
@@ -72,11 +72,6 @@ spinlock_t tdb_lock;
 
 /*
  * $Log: ipsec_xform.c,v $
- * Revision 1.65.2.1  2006-10-06 21:39:26  paul
- * Fix for 2.6.18+ only include linux/config.h if AUTOCONF_INCLUDED is not
- * set. This is defined through autoconf.h which is included through the
- * linux kernel build macros.
- *
  * Revision 1.65  2005/04/29 05:10:22  mcr
  * 	removed from extraenous includes to make unit testing easier.
  *
