@@ -1,4 +1,4 @@
-/* 
+ /* 
  * IKEv2 parent SA creation routines
  * Copyright (C) 2007  Michael Richardson <mcr@xelerance.com>
  *
@@ -1001,6 +1001,7 @@ static stf_status ikev2_send_auth(struct connection *c
 	
     } else if(c->policy & POLICY_PSK) {
 	/* todo */
+	if(!ikev2_calculate_psk_auth(pst, role, idhash_out, &a_pbs))
 	return STF_FAIL;
     } 
     
@@ -1345,7 +1346,20 @@ ikev2_parent_inI2outR2_tail(struct pluto_crypto_req_cont *pcrc
 						    , NULL /* gateways from DNS */
 						    , &md->chain[ISAKMP_NEXT_v2AUTH]->pbs);
 	if(authstat != STF_OK) {
-	    openswan_log("authentication failed");
+	    openswan_log("RSA authentication failed");
+	    SEND_NOTIFICATION(AUTHENTICATION_FAILED);
+	    return STF_FAIL;
+	}
+	break;
+    }
+    case v2_AUTH_SHARED:
+    {
+	stf_status authstat = ikev2_verify_psk_auth(st
+						    , RESPONDER
+						    , idhash_in
+						    , &md->chain[ISAKMP_NEXT_v2AUTH]->pbs);
+	if(authstat != STF_OK) {
+	    openswan_log("PSK authentication failed");
 	    SEND_NOTIFICATION(AUTHENTICATION_FAILED);
 	    return STF_FAIL;
 	}
@@ -1593,6 +1607,20 @@ stf_status ikev2parent_inR2(struct msg_digest *md)
 	}
 	break;
     }
+    case v2_AUTH_SHARED:
+    {
+	stf_status authstat = ikev2_verify_psk_auth(pst
+						    , INITIATOR 
+						    , idhash_in
+						    , &md->chain[ISAKMP_NEXT_v2AUTH]->pbs);
+	if(authstat != STF_OK) {
+	    openswan_log("PSK authentication failed");
+	    SEND_NOTIFICATION(AUTHENTICATION_FAILED);
+	    return STF_FAIL;
+	}
+	break;
+    }
+    
     default:
 	openswan_log("authentication method: %s not supported"
 		     , enum_name(&ikev2_auth_names
