@@ -11,7 +11,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: rcv_info.c,v 1.8.24.1 2005-07-26 02:11:23 ken Exp $
+ * RCSID $Id: rcv_info.c,v 1.10 2005/08/05 19:13:47 mcr Exp $
  */
 
 #include <stdio.h>
@@ -26,10 +26,10 @@
 #include <arpa/inet.h>
 #include <resolv.h>
 #include <arpa/nameser.h>	/* missing from <resolv.h> on old systems */
-#include <sys/queue.h>
 
 #include <openswan.h>
 
+#include "sysdep.h"
 #include "constants.h"
 #include "defs.h"
 #include "id.h"
@@ -151,7 +151,7 @@ info_lookuphostpair(struct ipsec_policy_cmd_query *ipcq)
     if (p2st->st_ah.present)
     {
 	ipcq->strength = IPSEC_PRIVACY_INTEGRAL;
-	ipcq->auth_detail = p2st->st_esp.attrs.auth;
+	ipcq->auth_detail = p2st->st_esp.attrs.transattrs.integ_hash;
     }
 
     if (p2st->st_esp.present)
@@ -160,7 +160,7 @@ info_lookuphostpair(struct ipsec_policy_cmd_query *ipcq)
 	 * XXX-mcr Please do not shout at me about relative strengths
 	 *         here. I'm not a cryptographer. I just diddle bits.
 	 */
-	switch (p2st->st_esp.attrs.transid)
+	switch (p2st->st_esp.attrs.transattrs.encrypt)
 	{
 	case ESP_NULL:
 	    /* actually, do not change it if we set it from AH */
@@ -192,11 +192,11 @@ info_lookuphostpair(struct ipsec_policy_cmd_query *ipcq)
 	    ipcq->bandwidth = IPSEC_QOS_FTP;
 	    break;
 	}
-	ipcq->esp_detail = p2st->st_esp.attrs.transid;
+	ipcq->esp_detail = p2st->st_esp.attrs.transattrs.encrypt;
     }
 
     if (p2st->st_ipcomp.present)
-	ipcq->comp_detail = p2st->st_esp.attrs.transid;
+	ipcq->comp_detail = p2st->st_esp.attrs.transattrs.encrypt;
 
     /* now! the credentails that were used */
     /* for the moment we only have 1 credential, the DNS name,
@@ -276,7 +276,7 @@ void
 info_handle(int infoctlfd)
 {
 	struct sockaddr_un info_client_addr;
-	int info_addr_len = sizeof(info_client_addr);
+	unsigned int info_addr_len = sizeof(info_client_addr);
 	/* Note: actual value in n should fit in int.  To print, cast to int. */
 	int infofd;
 	err_t err;
